# Body7

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**cidr_prefix** | **str** |  | 
**data_center_id** | **str** |  | 
**id** | **str** |  | 
**network_id** | **str** |  | 
**vrouter_size** | [**VRouterSize**](VRouterSize.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


